import request from '@/utils/request'

// 查询报文模版列表
export function messageTemplateTypeList() {
  return request({
    url: '/template/messageTemplateType/messageTemplateTypeList',
    method: 'post'
  })
}
// 添加报文
export function addMessageTemplate(data) {
  return request({
    url: '/template/messageTemplateType/addMessageType',
    method: 'post',
    data
  })
}
// 数据类型列表
export function findDataTypeList() {
  return request({
    url: '/template/dataType/dataTypeList',
    method: 'post'
  })
}
// 报文模版
export function templateList() {
  return request({
    url: '/template/template/templateList',
    method: 'post'
  })
}
//基础类型
export function findvehicleFoundationData(templatedId,code) {
  return request({
    url: '/template/messageTemplateType/findvehicleFoundationData?templatedId='+templatedId+"&code="+code,
    method: 'post'
  })
}
//数据类型
export function findvehicleData(templatedId,code) {
  return request({
    url: '/template/messageTemplateType/findvehicleData?templatedId='+templatedId+"&code="+code,
    method: 'post'
  })
}
//设备状态
export function finddeviceStatusData(templatedId,code) {
  return request({
    url: '/car/sysCar/findFenceByCarVin?templatedId='+templatedId+"&code="+code,
    method: 'post'
  })
}

//设备状态
export function findVehicleFaultData(param) {
  return request({
    url: '/template/messageTemplateType/finddeviceStatusData?carVin='+param,
    method: 'post'
  })
}

